==> qtjambi-help-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiHelp/QHelpSearchQuery_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpsearchengine.h>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpSearchQuery(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpSearchQuery")
    QHelpSearchQuery *_ptr = reinterpret_cast<QHelpSearchQuery *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpSearchQuery()
void __qt_construct_QHelpSearchQuery(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchQuery()")
    Q_UNUSED(__java_arguments)
    QHelpSearchQuery *__qt_this = new(__qtjambi_ptr) QHelpSearchQuery();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QHelpSearchQuery::QHelpSearchQuery()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_initialize_1native__Lio_qt_help_QHelpSearchQuery_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchQuery::QHelpSearchQuery()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchQuery, sizeof(QHelpSearchQuery), typeid(QHelpSearchQuery), false, &deleter_QHelpSearchQuery, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpSearchQuery(QHelpSearchQuery)
void __qt_construct_QHelpSearchQuery_cref_QHelpSearchQuery(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchQuery(QHelpSearchQuery)")
    jobject other0 = __java_arguments[0].l;
    const QHelpSearchQuery& __qt_other0 = qtjambi_cast<const QHelpSearchQuery& >(__jni_env, other0);
    QHelpSearchQuery *__qt_this = new(__qtjambi_ptr) QHelpSearchQuery(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_initialize_1native__Lio_qt_help_QHelpSearchQuery_2Lio_qt_help_QHelpSearchQuery_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchQuery_cref_QHelpSearchQuery, sizeof(QHelpSearchQuery), typeid(QHelpSearchQuery), false, &deleter_QHelpSearchQuery, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
void __qt_construct_QHelpSearchQuery_QHelpSearchQuery_FieldName_cref_QStringList(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)")
    QtJambiScope __qtjambi_scope;
    jobject field0 = __java_arguments[0].l;
    QHelpSearchQuery::FieldName __qt_field0 = qtjambi_cast<QHelpSearchQuery::FieldName>(__jni_env, field0);
    jobject wordList_1 = __java_arguments[1].l;
    const QStringList&  __qt_wordList_1 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, wordList_1);
    QHelpSearchQuery *__qt_this = new(__qtjambi_ptr) QHelpSearchQuery(QHelpSearchQuery::FieldName(__qt_field0), __qt_wordList_1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_initialize_1native__Lio_qt_help_QHelpSearchQuery_2Lio_qt_help_QHelpSearchQuery_00024FieldName_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject field0,
 jobject wordList_1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = field0;
        arguments[1].l = wordList_1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchQuery_QHelpSearchQuery_FieldName_cref_QStringList, sizeof(QHelpSearchQuery), typeid(QHelpSearchQuery), false, &deleter_QHelpSearchQuery, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QHelpSearchQuery
void __qt_destruct_QHelpSearchQuery(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpSearchQuery")
    reinterpret_cast<QHelpSearchQuery*>(ptr)->~QHelpSearchQuery();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_setFieldName_1native_1cref_1QHelpSearchQuery_1FieldName__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint fieldName0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QHelpSearchQuery::FieldName __qt_fieldName0 = qtjambi_cast<QHelpSearchQuery::FieldName>(__jni_env, fieldName0);
        __qt_this->fieldName = QHelpSearchQuery::FieldName(__qt_fieldName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_fieldName_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QHelpSearchQuery::FieldName&  __qt_value = __qt_this->fieldName;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_setWordList_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject wordList0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringList&  __qt_wordList0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, wordList0);
        __qt_this->wordList = __qt_wordList0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_wordList_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringList&  __qt_value = __qt_this->wordList;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpSearchQuery(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpSearchQuery>("QHelpSearchQuery", "io/qt/help/QHelpSearchQuery");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpSearchQuery, {
        ConstructorInfo(&__qt_construct_QHelpSearchQuery, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpSearchQuery_cref_QHelpSearchQuery, "Lio/qt/help/QHelpSearchQuery;")
       ,ConstructorInfo(&__qt_construct_QHelpSearchQuery_QHelpSearchQuery_FieldName_cref_QStringList, "Lio/qt/help/QHelpSearchQuery$FieldName;Ljava/util/Collection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpSearchQuery);
    registerMetaType<QHelpSearchQuery>("QHelpSearchQuery");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QHelpSearchQuery::FieldName>("QHelpSearchQuery::FieldName", "io/qt/help/QHelpSearchQuery$FieldName");
// END: enums and flags
}

==> qtjambi-help-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiHelp/QHelpSearchQuery_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtHelp/qhelpsearchengine.h>
#include <QtCore/QVariant>
#include <QtCore/QStringList>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QHelpSearchQuery(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QHelpSearchQuery")
    QHelpSearchQuery *_ptr = reinterpret_cast<QHelpSearchQuery *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QHelpSearchQuery()
void __qt_construct_QHelpSearchQuery_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchQuery()")
    Q_UNUSED(__java_arguments)
    QHelpSearchQuery *__qt_this = new(__qtjambi_ptr) QHelpSearchQuery();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
void __qt_construct_QHelpSearchQuery_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)")
    QtJambiScope __qtjambi_scope;
    jobject field0 = __java_arguments[0].l;
    QHelpSearchQuery::FieldName __qt_field0 = qtjambi_cast<QHelpSearchQuery::FieldName>(__jni_env, field0);
    jobject wordList_1 = __java_arguments[1].l;
    const QStringList&  __qt_wordList_1 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, wordList_1);
    QHelpSearchQuery *__qt_this = new(__qtjambi_ptr) QHelpSearchQuery(QHelpSearchQuery::FieldName(__qt_field0), __qt_wordList_1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QHelpSearchQuery
void __qt_destruct_QHelpSearchQuery(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QHelpSearchQuery")
    reinterpret_cast<QHelpSearchQuery*>(ptr)->~QHelpSearchQuery();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QHelpSearchQuery::QHelpSearchQuery()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_initialize_1native__Lio_qt_help_QHelpSearchQuery_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchQuery::QHelpSearchQuery()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchQuery_0, sizeof(QHelpSearchQuery), typeid(QHelpSearchQuery), false, &deleter_QHelpSearchQuery, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_initialize_1native__Lio_qt_help_QHelpSearchQuery_2Lio_qt_help_QHelpSearchQuery_00024FieldName_2Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject field0,
 jobject wordList_1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName,QStringList)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = field0;
        arguments[1].l = wordList_1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QHelpSearchQuery_1, sizeof(QHelpSearchQuery), typeid(QHelpSearchQuery), false, &deleter_QHelpSearchQuery, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_setFieldName_1native_1cref_1QHelpSearchQuery_1FieldName__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint fieldName0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QHelpSearchQuery::FieldName __qt_fieldName0 = qtjambi_cast<QHelpSearchQuery::FieldName>(__jni_env, fieldName0);
        __qt_this->fieldName = QHelpSearchQuery::FieldName(__qt_fieldName0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_fieldName_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QHelpSearchQuery::FieldName&  __qt_value = __qt_this->fieldName;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_setWordList_1native_1cref_1QStringList__JLjava_util_Collection_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject wordList0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringList&  __qt_wordList0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, wordList0);
        __qt_this->wordList = __qt_wordList0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_wordList_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QStringList&  __qt_value = __qt_this->wordList;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_help_QHelpSearchQuery_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QHelpSearchQuery *__qt_this = QtJambiAPI::objectFromNativeId<QHelpSearchQuery>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QHelpSearchQuery(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QHelpSearchQuery>("QHelpSearchQuery", "io/qt/help/QHelpSearchQuery");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QHelpSearchQuery, {
        ConstructorInfo(&__qt_construct_QHelpSearchQuery_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QHelpSearchQuery_1, "Lio/qt/help/QHelpSearchQuery$FieldName;Ljava/util/Collection;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QHelpSearchQuery);
    registerMetaType<QHelpSearchQuery>("QHelpSearchQuery");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QHelpSearchQuery::FieldName>("QHelpSearchQuery::FieldName", "io/qt/help/QHelpSearchQuery$FieldName");
// END: enums and flags
}
